==> haskell-x11-xft-0.3.1-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11-xft
version: 0.3.1
id: X11-xft-0.3.1-6yn4Mn0GaIL5FnhdB6WPd2
key: X11-xft-0.3.1-6yn4Mn0GaIL5FnhdB6WPd2
license: LicenseRef-LGPL
maintainer: clemens@endorphin.org
author: Clemens Fruhwirth
synopsis: Bindings to the Xft, X Free Type interface library, and some Xrender parts
description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts
category: Graphics
abi: 5d1cc28ad5219670d4029c34d680373a
exposed: True
exposed-modules:
    Graphics.X11.Xft Graphics.X11.Xrender
import-dirs: /usr/lib/ghc-8.4.3/site-local/X11-xft-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/X11-xft-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/X11-xft-0.3.1
hs-libraries: HSX11-xft-0.3.1-6yn4Mn0GaIL5FnhdB6WPd2
extra-libraries:
    Xft
include-dirs: /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/uuid
depends:
    X11-1.8-2GHfNeKQbxBLmODzL3h52l base-4.11.1.0
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
abi-depends: X11-1.8-2GHfNeKQbxBLmODzL3h52l=e42fc8f90fd0f132c1dc5712a1c8a0c8
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
haddock-interfaces: /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html: /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-xft-0.3.1-36-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11-xft
version: 0.3.1
id: X11-xft-0.3.1-2RD5bsRcgnFFo2Kc2faM0W
key: X11-xft-0.3.1-2RD5bsRcgnFFo2Kc2faM0W
license: LicenseRef-LGPL
maintainer: clemens@endorphin.org
author: Clemens Fruhwirth
synopsis: Bindings to the Xft, X Free Type interface library, and some Xrender parts
description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts
category: Graphics
abi: 14c062d9c29e21358a7756adabff3298
exposed: True
exposed-modules:
    Graphics.X11.Xft Graphics.X11.Xrender
import-dirs: /usr/lib/ghc-8.4.3/site-local/X11-xft-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/X11-xft-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/X11-xft-0.3.1
hs-libraries: HSX11-xft-0.3.1-2RD5bsRcgnFFo2Kc2faM0W
extra-libraries:
    Xft
include-dirs: /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/uuid
depends:
    X11-1.9-72pXPIWotOnFLesP8FyvXP base-4.11.1.0
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
abi-depends: X11-1.9-72pXPIWotOnFLesP8FyvXP=b01ffd1213d929ac2306d0913c55f13b
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
haddock-interfaces: /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html: /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
